@@ -177,30 +177,30 @@ class ApiGatewayToKinesisStreams(
 
         jsii.create(ApiGatewayToKinesisStreams, self, [scope, id, props])
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
-        return jsii.get(self, "apiGateway")
+        return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGatewayCloudWatchRole")
     def api_gateway_cloud_watch_role(self) -> aws_cdk.aws_iam.Role:
-        return jsii.get(self, "apiGatewayCloudWatchRole")
+        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "apiGatewayCloudWatchRole"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGatewayLogGroup")
     def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
-        return jsii.get(self, "apiGatewayLogGroup")
+        return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGatewayRole")
     def api_gateway_role(self) -> aws_cdk.aws_iam.Role:
-        return jsii.get(self, "apiGatewayRole")
+        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "apiGatewayRole"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
-        return jsii.get(self, "kinesisStream")
+        return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
 
 
 @jsii.data_type(
@@ -277,7 +277,7 @@ class ApiGatewayToKinesisStreamsProps:
         :default: - Default properties are used.
         """
         result = self._values.get("api_gateway_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_apigateway.RestApiProps], result)
 
     @builtins.property
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
@@ -286,7 +286,7 @@ class ApiGatewayToKinesisStreamsProps:
         :default: - None
         """
         result = self._values.get("existing_stream_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.Stream], result)
 
     @builtins.property
     def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
@@ -295,7 +295,7 @@ class ApiGatewayToKinesisStreamsProps:
         :default: - Default properties are used.
         """
         result = self._values.get("kinesis_stream_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.StreamProps], result)
 
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
@@ -304,7 +304,7 @@ class ApiGatewayToKinesisStreamsProps:
         :default: - Default props are used
         """
         result = self._values.get("log_group_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
 
     @builtins.property
     def put_record_request_model(
@@ -320,7 +320,7 @@ class ApiGatewayToKinesisStreamsProps:
         "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}
         """
         result = self._values.get("put_record_request_model")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_apigateway.ModelOptions], result)
 
     @builtins.property
     def put_record_request_template(self) -> typing.Optional[builtins.str]:
@@ -334,7 +334,7 @@ class ApiGatewayToKinesisStreamsProps:
         "PartitionKey": "$input.path('$.partitionKey')" }
         """
         result = self._values.get("put_record_request_template")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def put_records_request_model(
@@ -351,7 +351,7 @@ class ApiGatewayToKinesisStreamsProps:
         "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}}}}
         """
         result = self._values.get("put_records_request_model")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_apigateway.ModelOptions], result)
 
     @builtins.property
     def put_records_request_template(self) -> typing.Optional[builtins.str]:
@@ -365,7 +365,7 @@ class ApiGatewayToKinesisStreamsProps:
         { "Data": "$util.base64Encode($elem.data)", "PartitionKey": "$elem.partitionKey"}#if($foreach.hasNext),#end #end ] }
         """
         result = self._values.get("put_records_request_template")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
